### Name: genoud
### Title: GENetic Optimization Using Derivatives
### Aliases: genoud
### Keywords: optimize nonlinear

### ** Examples

#maximize the sin function
 sin1 <- genoud(sin, nvars=1, max=TRUE);

#minimize the sin function
 sin2 <- genoud(sin, nvars=1, max=FALSE);

#maximize a univariate normal mixture which looks like a claw
claw <- function(xx) {
  Nd <- function(x, mu, sigma) {
    w <- (1.0/sqrt(2.0*pi*sigma*sigma)) ;
    z <- (x-mu)/sigma;
    w <- w*exp(-0.5*z*z) ;
    as.double(w);
  }
  x <- xx[1];
  y <- (0.46*(Nd(x,-1.0,2.0/3.0) + Nd(x,1.0,2.0/3.0)) +
           (1.0/300.0)*(Nd(x,-0.5,.01) + Nd(x,-1.0,.01) + Nd(x,-1.5,.01)) +
           (7.0/300.0)*(Nd(x,0.5,.07) + Nd(x,1.0,.07) + Nd(x,1.5,.07))) ;
  as.double(y);
}
 claw1   <- genoud(claw, nvars=1,P9=100,max=TRUE);

## Not run: 
##D #Plot the previous run
##D xx <- seq(-3,3,.05);
##D plot(xx,lapply(xx,claw),type="l",xlab="Parameter",ylab="Fit",main="GENOUD: Maximize the Claw Density");
##D points(claw1$par,claw1$value,col="red");
##D 
##D # Maximize a bivariate normal mixture which looks like a claw.
##D biclaw <- function(xx) {
##D   mNd2 <- function(x1, x2, mu1, mu2, sigma1, sigma2, rho)
##D     {
##D       z1 <- (x1-mu1)/sigma1;
##D       z2 <- (x2-mu2)/sigma2;
##D       w <- (1.0/(2.0*pi*sigma1*sigma2*sqrt(1-rho*rho))) ;
##D       w <- w*exp(-0.5*(z1*z1 - 2*rho*z1*z2 + z2*z2)/(1-rho*rho)) ;
##D       as.double(w);
##D     }
##D   x1 <- xx[1]+1;
##D   x2 <- xx[2]+1;
##D   
##D   y <- (0.5*mNd2(x1,x2,0.0,0.0,1.0,1.0,0.0) +
##D             0.1*(mNd2(x1,x2,-1.0,-1.0,0.1,0.1,0.0) +
##D                  mNd2(x1,x2,-0.5,-0.5,0.1,0.1,0.0) +
##D                  mNd2(x1,x2,0.0,0.0,0.1,0.1,0.0) +
##D                  mNd2(x1,x2,0.5,0.5,0.1,0.1,0.0) +
##D                  mNd2(x1,x2,1.0,1.0,0.1,0.1,0.0)));
##D 
##D   as.double(y);
##D }
##D biclaw1 <- genoud(biclaw, default.domains=20, nvars=2,P9=100,max=TRUE);
## End(Not run)
# For more examples see: http://sekhon.berkeley.edu/rgenoud/R.



